Inmanta Reference — Inmanta 2017.1.1 documentation

# Inmanta Reference

Welcome to the Inmanta reference guide!

Here we explain all the features and options of Inmanta. If you’re just looking to get started with Inmanta, please check out the Quickstart guide.

- Language Reference
  - Modules
  - Variables
  - Literals values
  - Primitive types
  - Conditions
  - Function calls
  - Entities
  - Relations
  - New Relation syntax
  - Instantiation
  - Refinements
  - Indexes and queries
  - For loop
  - Transformations
    - String interpolation
    - Templates
  - Plug-ins
  - Resources
- Command Reference
  - inmanta
  - inmanta-cli
- Configuration Reference
  - agent_rest_transport
  - client_rest_transport
  - cmdline_rest_transport
  - compiler_rest_transport
  - config
  - dashboard
  - database
  - server
  - server_rest_transport
  - unknown_handler
- Administration Guide
  - Deployment models
    - Embedded
    - Push to server
    - Autonomous server
  - Server side agents
  - Local Agents
- Module Developers Guide
- Platform Developers Guide